# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ZoneArgs', 'Zone']

@pulumi.input_type
class ZoneArgs:
    def __init__(__self__, *,
                 zone: pulumi.Input[str],
                 additional_ports: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 additional_primaries: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 autogenerate_ns_record: Optional[pulumi.Input[bool]] = None,
                 dnssec: Optional[pulumi.Input[bool]] = None,
                 expiry: Optional[pulumi.Input[int]] = None,
                 hostmaster: Optional[pulumi.Input[str]] = None,
                 link: Optional[pulumi.Input[str]] = None,
                 networks: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 nx_ttl: Optional[pulumi.Input[int]] = None,
                 primary: Optional[pulumi.Input[str]] = None,
                 primary_port: Optional[pulumi.Input[int]] = None,
                 refresh: Optional[pulumi.Input[int]] = None,
                 retry: Optional[pulumi.Input[int]] = None,
                 secondaries: Optional[pulumi.Input[Sequence[pulumi.Input['ZoneSecondaryArgs']]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tsig: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 ttl: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a Zone resource.
        :param pulumi.Input[str] zone: The domain name of the zone.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] additional_primaries: List of additional IPv4 addresses for the primary
               zone. Conflicts with `secondaries`.
        :param pulumi.Input[bool] dnssec: Whether or not DNSSEC is enabled for the zone.
               Note that DNSSEC must be enabled on the account by support for this to be set
               to `true`.
        :param pulumi.Input[int] expiry: The SOA Expiry. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[str] hostmaster: (Computed) The SOA Hostmaster.
        :param pulumi.Input[str] link: The target zone(domain name) to link to.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] networks: List of network IDs for which the zone is
               available. If no network is provided, the zone will be created in network 0,
               the primary NS1 Global Network.
        :param pulumi.Input[int] nx_ttl: The SOA NX TTL. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[str] primary: The primary zones' IPv4 address. This makes the zone a
               secondary. Conflicts with `secondaries`.
        :param pulumi.Input[int] refresh: The SOA Refresh. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[int] retry: The SOA Retry. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[Sequence[pulumi.Input['ZoneSecondaryArgs']]] secondaries: List of secondary servers. This makes the zone a
               primary. Conflicts with `primary` and `additional_primaries`.
               Secondaries is documented below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: map of tags in the form of `"key" = "value"` where both key and value are strings
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tsig: TSIG is documented below
        :param pulumi.Input[int] ttl: The SOA TTL.
        """
        pulumi.set(__self__, "zone", zone)
        if additional_ports is not None:
            pulumi.set(__self__, "additional_ports", additional_ports)
        if additional_primaries is not None:
            pulumi.set(__self__, "additional_primaries", additional_primaries)
        if autogenerate_ns_record is not None:
            pulumi.set(__self__, "autogenerate_ns_record", autogenerate_ns_record)
        if dnssec is not None:
            pulumi.set(__self__, "dnssec", dnssec)
        if expiry is not None:
            pulumi.set(__self__, "expiry", expiry)
        if hostmaster is not None:
            pulumi.set(__self__, "hostmaster", hostmaster)
        if link is not None:
            pulumi.set(__self__, "link", link)
        if networks is not None:
            pulumi.set(__self__, "networks", networks)
        if nx_ttl is not None:
            pulumi.set(__self__, "nx_ttl", nx_ttl)
        if primary is not None:
            pulumi.set(__self__, "primary", primary)
        if primary_port is not None:
            pulumi.set(__self__, "primary_port", primary_port)
        if refresh is not None:
            pulumi.set(__self__, "refresh", refresh)
        if retry is not None:
            pulumi.set(__self__, "retry", retry)
        if secondaries is not None:
            pulumi.set(__self__, "secondaries", secondaries)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tsig is not None:
            pulumi.set(__self__, "tsig", tsig)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Input[str]:
        """
        The domain name of the zone.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: pulumi.Input[str]):
        pulumi.set(self, "zone", value)

    @property
    @pulumi.getter(name="additionalPorts")
    def additional_ports(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        return pulumi.get(self, "additional_ports")

    @additional_ports.setter
    def additional_ports(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "additional_ports", value)

    @property
    @pulumi.getter(name="additionalPrimaries")
    def additional_primaries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of additional IPv4 addresses for the primary
        zone. Conflicts with `secondaries`.
        """
        return pulumi.get(self, "additional_primaries")

    @additional_primaries.setter
    def additional_primaries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "additional_primaries", value)

    @property
    @pulumi.getter(name="autogenerateNsRecord")
    def autogenerate_ns_record(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "autogenerate_ns_record")

    @autogenerate_ns_record.setter
    def autogenerate_ns_record(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "autogenerate_ns_record", value)

    @property
    @pulumi.getter
    def dnssec(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether or not DNSSEC is enabled for the zone.
        Note that DNSSEC must be enabled on the account by support for this to be set
        to `true`.
        """
        return pulumi.get(self, "dnssec")

    @dnssec.setter
    def dnssec(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dnssec", value)

    @property
    @pulumi.getter
    def expiry(self) -> Optional[pulumi.Input[int]]:
        """
        The SOA Expiry. Conflicts with `primary` and
        `additional_primaries` (default must be accepted).
        """
        return pulumi.get(self, "expiry")

    @expiry.setter
    def expiry(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "expiry", value)

    @property
    @pulumi.getter
    def hostmaster(self) -> Optional[pulumi.Input[str]]:
        """
        (Computed) The SOA Hostmaster.
        """
        return pulumi.get(self, "hostmaster")

    @hostmaster.setter
    def hostmaster(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hostmaster", value)

    @property
    @pulumi.getter
    def link(self) -> Optional[pulumi.Input[str]]:
        """
        The target zone(domain name) to link to.
        """
        return pulumi.get(self, "link")

    @link.setter
    def link(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "link", value)

    @property
    @pulumi.getter
    def networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        List of network IDs for which the zone is
        available. If no network is provided, the zone will be created in network 0,
        the primary NS1 Global Network.
        """
        return pulumi.get(self, "networks")

    @networks.setter
    def networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "networks", value)

    @property
    @pulumi.getter(name="nxTtl")
    def nx_ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The SOA NX TTL. Conflicts with `primary` and
        `additional_primaries` (default must be accepted).
        """
        return pulumi.get(self, "nx_ttl")

    @nx_ttl.setter
    def nx_ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "nx_ttl", value)

    @property
    @pulumi.getter
    def primary(self) -> Optional[pulumi.Input[str]]:
        """
        The primary zones' IPv4 address. This makes the zone a
        secondary. Conflicts with `secondaries`.
        """
        return pulumi.get(self, "primary")

    @primary.setter
    def primary(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "primary", value)

    @property
    @pulumi.getter(name="primaryPort")
    def primary_port(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "primary_port")

    @primary_port.setter
    def primary_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "primary_port", value)

    @property
    @pulumi.getter
    def refresh(self) -> Optional[pulumi.Input[int]]:
        """
        The SOA Refresh. Conflicts with `primary` and
        `additional_primaries` (default must be accepted).
        """
        return pulumi.get(self, "refresh")

    @refresh.setter
    def refresh(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "refresh", value)

    @property
    @pulumi.getter
    def retry(self) -> Optional[pulumi.Input[int]]:
        """
        The SOA Retry. Conflicts with `primary` and
        `additional_primaries` (default must be accepted).
        """
        return pulumi.get(self, "retry")

    @retry.setter
    def retry(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "retry", value)

    @property
    @pulumi.getter
    def secondaries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ZoneSecondaryArgs']]]]:
        """
        List of secondary servers. This makes the zone a
        primary. Conflicts with `primary` and `additional_primaries`.
        Secondaries is documented below.
        """
        return pulumi.get(self, "secondaries")

    @secondaries.setter
    def secondaries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ZoneSecondaryArgs']]]]):
        pulumi.set(self, "secondaries", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        map of tags in the form of `"key" = "value"` where both key and value are strings
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def tsig(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        TSIG is documented below
        """
        return pulumi.get(self, "tsig")

    @tsig.setter
    def tsig(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tsig", value)

    @property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The SOA TTL.
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ttl", value)


@pulumi.input_type
class _ZoneState:
    def __init__(__self__, *,
                 additional_ports: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 additional_primaries: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 autogenerate_ns_record: Optional[pulumi.Input[bool]] = None,
                 dns_servers: Optional[pulumi.Input[str]] = None,
                 dnssec: Optional[pulumi.Input[bool]] = None,
                 expiry: Optional[pulumi.Input[int]] = None,
                 hostmaster: Optional[pulumi.Input[str]] = None,
                 link: Optional[pulumi.Input[str]] = None,
                 networks: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 nx_ttl: Optional[pulumi.Input[int]] = None,
                 primary: Optional[pulumi.Input[str]] = None,
                 primary_port: Optional[pulumi.Input[int]] = None,
                 refresh: Optional[pulumi.Input[int]] = None,
                 retry: Optional[pulumi.Input[int]] = None,
                 secondaries: Optional[pulumi.Input[Sequence[pulumi.Input['ZoneSecondaryArgs']]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tsig: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 ttl: Optional[pulumi.Input[int]] = None,
                 zone: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Zone resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] additional_primaries: List of additional IPv4 addresses for the primary
               zone. Conflicts with `secondaries`.
        :param pulumi.Input[str] dns_servers: (Computed) Authoritative Name Servers.
        :param pulumi.Input[bool] dnssec: Whether or not DNSSEC is enabled for the zone.
               Note that DNSSEC must be enabled on the account by support for this to be set
               to `true`.
        :param pulumi.Input[int] expiry: The SOA Expiry. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[str] hostmaster: (Computed) The SOA Hostmaster.
        :param pulumi.Input[str] link: The target zone(domain name) to link to.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] networks: List of network IDs for which the zone is
               available. If no network is provided, the zone will be created in network 0,
               the primary NS1 Global Network.
        :param pulumi.Input[int] nx_ttl: The SOA NX TTL. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[str] primary: The primary zones' IPv4 address. This makes the zone a
               secondary. Conflicts with `secondaries`.
        :param pulumi.Input[int] refresh: The SOA Refresh. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[int] retry: The SOA Retry. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[Sequence[pulumi.Input['ZoneSecondaryArgs']]] secondaries: List of secondary servers. This makes the zone a
               primary. Conflicts with `primary` and `additional_primaries`.
               Secondaries is documented below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: map of tags in the form of `"key" = "value"` where both key and value are strings
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tsig: TSIG is documented below
        :param pulumi.Input[int] ttl: The SOA TTL.
        :param pulumi.Input[str] zone: The domain name of the zone.
        """
        if additional_ports is not None:
            pulumi.set(__self__, "additional_ports", additional_ports)
        if additional_primaries is not None:
            pulumi.set(__self__, "additional_primaries", additional_primaries)
        if autogenerate_ns_record is not None:
            pulumi.set(__self__, "autogenerate_ns_record", autogenerate_ns_record)
        if dns_servers is not None:
            pulumi.set(__self__, "dns_servers", dns_servers)
        if dnssec is not None:
            pulumi.set(__self__, "dnssec", dnssec)
        if expiry is not None:
            pulumi.set(__self__, "expiry", expiry)
        if hostmaster is not None:
            pulumi.set(__self__, "hostmaster", hostmaster)
        if link is not None:
            pulumi.set(__self__, "link", link)
        if networks is not None:
            pulumi.set(__self__, "networks", networks)
        if nx_ttl is not None:
            pulumi.set(__self__, "nx_ttl", nx_ttl)
        if primary is not None:
            pulumi.set(__self__, "primary", primary)
        if primary_port is not None:
            pulumi.set(__self__, "primary_port", primary_port)
        if refresh is not None:
            pulumi.set(__self__, "refresh", refresh)
        if retry is not None:
            pulumi.set(__self__, "retry", retry)
        if secondaries is not None:
            pulumi.set(__self__, "secondaries", secondaries)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tsig is not None:
            pulumi.set(__self__, "tsig", tsig)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter(name="additionalPorts")
    def additional_ports(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        return pulumi.get(self, "additional_ports")

    @additional_ports.setter
    def additional_ports(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "additional_ports", value)

    @property
    @pulumi.getter(name="additionalPrimaries")
    def additional_primaries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of additional IPv4 addresses for the primary
        zone. Conflicts with `secondaries`.
        """
        return pulumi.get(self, "additional_primaries")

    @additional_primaries.setter
    def additional_primaries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "additional_primaries", value)

    @property
    @pulumi.getter(name="autogenerateNsRecord")
    def autogenerate_ns_record(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "autogenerate_ns_record")

    @autogenerate_ns_record.setter
    def autogenerate_ns_record(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "autogenerate_ns_record", value)

    @property
    @pulumi.getter(name="dnsServers")
    def dns_servers(self) -> Optional[pulumi.Input[str]]:
        """
        (Computed) Authoritative Name Servers.
        """
        return pulumi.get(self, "dns_servers")

    @dns_servers.setter
    def dns_servers(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dns_servers", value)

    @property
    @pulumi.getter
    def dnssec(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether or not DNSSEC is enabled for the zone.
        Note that DNSSEC must be enabled on the account by support for this to be set
        to `true`.
        """
        return pulumi.get(self, "dnssec")

    @dnssec.setter
    def dnssec(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dnssec", value)

    @property
    @pulumi.getter
    def expiry(self) -> Optional[pulumi.Input[int]]:
        """
        The SOA Expiry. Conflicts with `primary` and
        `additional_primaries` (default must be accepted).
        """
        return pulumi.get(self, "expiry")

    @expiry.setter
    def expiry(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "expiry", value)

    @property
    @pulumi.getter
    def hostmaster(self) -> Optional[pulumi.Input[str]]:
        """
        (Computed) The SOA Hostmaster.
        """
        return pulumi.get(self, "hostmaster")

    @hostmaster.setter
    def hostmaster(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hostmaster", value)

    @property
    @pulumi.getter
    def link(self) -> Optional[pulumi.Input[str]]:
        """
        The target zone(domain name) to link to.
        """
        return pulumi.get(self, "link")

    @link.setter
    def link(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "link", value)

    @property
    @pulumi.getter
    def networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        List of network IDs for which the zone is
        available. If no network is provided, the zone will be created in network 0,
        the primary NS1 Global Network.
        """
        return pulumi.get(self, "networks")

    @networks.setter
    def networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "networks", value)

    @property
    @pulumi.getter(name="nxTtl")
    def nx_ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The SOA NX TTL. Conflicts with `primary` and
        `additional_primaries` (default must be accepted).
        """
        return pulumi.get(self, "nx_ttl")

    @nx_ttl.setter
    def nx_ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "nx_ttl", value)

    @property
    @pulumi.getter
    def primary(self) -> Optional[pulumi.Input[str]]:
        """
        The primary zones' IPv4 address. This makes the zone a
        secondary. Conflicts with `secondaries`.
        """
        return pulumi.get(self, "primary")

    @primary.setter
    def primary(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "primary", value)

    @property
    @pulumi.getter(name="primaryPort")
    def primary_port(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "primary_port")

    @primary_port.setter
    def primary_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "primary_port", value)

    @property
    @pulumi.getter
    def refresh(self) -> Optional[pulumi.Input[int]]:
        """
        The SOA Refresh. Conflicts with `primary` and
        `additional_primaries` (default must be accepted).
        """
        return pulumi.get(self, "refresh")

    @refresh.setter
    def refresh(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "refresh", value)

    @property
    @pulumi.getter
    def retry(self) -> Optional[pulumi.Input[int]]:
        """
        The SOA Retry. Conflicts with `primary` and
        `additional_primaries` (default must be accepted).
        """
        return pulumi.get(self, "retry")

    @retry.setter
    def retry(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "retry", value)

    @property
    @pulumi.getter
    def secondaries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ZoneSecondaryArgs']]]]:
        """
        List of secondary servers. This makes the zone a
        primary. Conflicts with `primary` and `additional_primaries`.
        Secondaries is documented below.
        """
        return pulumi.get(self, "secondaries")

    @secondaries.setter
    def secondaries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ZoneSecondaryArgs']]]]):
        pulumi.set(self, "secondaries", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        map of tags in the form of `"key" = "value"` where both key and value are strings
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def tsig(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        TSIG is documented below
        """
        return pulumi.get(self, "tsig")

    @tsig.setter
    def tsig(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tsig", value)

    @property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The SOA TTL.
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ttl", value)

    @property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[str]]:
        """
        The domain name of the zone.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "zone", value)


class Zone(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_ports: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 additional_primaries: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 autogenerate_ns_record: Optional[pulumi.Input[bool]] = None,
                 dnssec: Optional[pulumi.Input[bool]] = None,
                 expiry: Optional[pulumi.Input[int]] = None,
                 hostmaster: Optional[pulumi.Input[str]] = None,
                 link: Optional[pulumi.Input[str]] = None,
                 networks: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 nx_ttl: Optional[pulumi.Input[int]] = None,
                 primary: Optional[pulumi.Input[str]] = None,
                 primary_port: Optional[pulumi.Input[int]] = None,
                 refresh: Optional[pulumi.Input[int]] = None,
                 retry: Optional[pulumi.Input[int]] = None,
                 secondaries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ZoneSecondaryArgs', 'ZoneSecondaryArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tsig: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 ttl: Optional[pulumi.Input[int]] = None,
                 zone: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Import

        ```sh
        $ pulumi import ns1:index/zone:Zone <name> <zone>`
        ```

        So for the example above:

        ```sh
        $ pulumi import ns1:index/zone:Zone example terraform.example.io`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] additional_primaries: List of additional IPv4 addresses for the primary
               zone. Conflicts with `secondaries`.
        :param pulumi.Input[bool] dnssec: Whether or not DNSSEC is enabled for the zone.
               Note that DNSSEC must be enabled on the account by support for this to be set
               to `true`.
        :param pulumi.Input[int] expiry: The SOA Expiry. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[str] hostmaster: (Computed) The SOA Hostmaster.
        :param pulumi.Input[str] link: The target zone(domain name) to link to.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] networks: List of network IDs for which the zone is
               available. If no network is provided, the zone will be created in network 0,
               the primary NS1 Global Network.
        :param pulumi.Input[int] nx_ttl: The SOA NX TTL. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[str] primary: The primary zones' IPv4 address. This makes the zone a
               secondary. Conflicts with `secondaries`.
        :param pulumi.Input[int] refresh: The SOA Refresh. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[int] retry: The SOA Retry. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[Sequence[pulumi.Input[Union['ZoneSecondaryArgs', 'ZoneSecondaryArgsDict']]]] secondaries: List of secondary servers. This makes the zone a
               primary. Conflicts with `primary` and `additional_primaries`.
               Secondaries is documented below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: map of tags in the form of `"key" = "value"` where both key and value are strings
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tsig: TSIG is documented below
        :param pulumi.Input[int] ttl: The SOA TTL.
        :param pulumi.Input[str] zone: The domain name of the zone.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ZoneArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        ```sh
        $ pulumi import ns1:index/zone:Zone <name> <zone>`
        ```

        So for the example above:

        ```sh
        $ pulumi import ns1:index/zone:Zone example terraform.example.io`
        ```

        :param str resource_name: The name of the resource.
        :param ZoneArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ZoneArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_ports: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 additional_primaries: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 autogenerate_ns_record: Optional[pulumi.Input[bool]] = None,
                 dnssec: Optional[pulumi.Input[bool]] = None,
                 expiry: Optional[pulumi.Input[int]] = None,
                 hostmaster: Optional[pulumi.Input[str]] = None,
                 link: Optional[pulumi.Input[str]] = None,
                 networks: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 nx_ttl: Optional[pulumi.Input[int]] = None,
                 primary: Optional[pulumi.Input[str]] = None,
                 primary_port: Optional[pulumi.Input[int]] = None,
                 refresh: Optional[pulumi.Input[int]] = None,
                 retry: Optional[pulumi.Input[int]] = None,
                 secondaries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ZoneSecondaryArgs', 'ZoneSecondaryArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tsig: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 ttl: Optional[pulumi.Input[int]] = None,
                 zone: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ZoneArgs.__new__(ZoneArgs)

            __props__.__dict__["additional_ports"] = additional_ports
            __props__.__dict__["additional_primaries"] = additional_primaries
            __props__.__dict__["autogenerate_ns_record"] = autogenerate_ns_record
            __props__.__dict__["dnssec"] = dnssec
            __props__.__dict__["expiry"] = expiry
            __props__.__dict__["hostmaster"] = hostmaster
            __props__.__dict__["link"] = link
            __props__.__dict__["networks"] = networks
            __props__.__dict__["nx_ttl"] = nx_ttl
            __props__.__dict__["primary"] = primary
            __props__.__dict__["primary_port"] = primary_port
            __props__.__dict__["refresh"] = refresh
            __props__.__dict__["retry"] = retry
            __props__.__dict__["secondaries"] = secondaries
            __props__.__dict__["tags"] = tags
            __props__.__dict__["tsig"] = tsig
            __props__.__dict__["ttl"] = ttl
            if zone is None and not opts.urn:
                raise TypeError("Missing required property 'zone'")
            __props__.__dict__["zone"] = zone
            __props__.__dict__["dns_servers"] = None
        super(Zone, __self__).__init__(
            'ns1:index/zone:Zone',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            additional_ports: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
            additional_primaries: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            autogenerate_ns_record: Optional[pulumi.Input[bool]] = None,
            dns_servers: Optional[pulumi.Input[str]] = None,
            dnssec: Optional[pulumi.Input[bool]] = None,
            expiry: Optional[pulumi.Input[int]] = None,
            hostmaster: Optional[pulumi.Input[str]] = None,
            link: Optional[pulumi.Input[str]] = None,
            networks: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
            nx_ttl: Optional[pulumi.Input[int]] = None,
            primary: Optional[pulumi.Input[str]] = None,
            primary_port: Optional[pulumi.Input[int]] = None,
            refresh: Optional[pulumi.Input[int]] = None,
            retry: Optional[pulumi.Input[int]] = None,
            secondaries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ZoneSecondaryArgs', 'ZoneSecondaryArgsDict']]]]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            tsig: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            ttl: Optional[pulumi.Input[int]] = None,
            zone: Optional[pulumi.Input[str]] = None) -> 'Zone':
        """
        Get an existing Zone resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] additional_primaries: List of additional IPv4 addresses for the primary
               zone. Conflicts with `secondaries`.
        :param pulumi.Input[str] dns_servers: (Computed) Authoritative Name Servers.
        :param pulumi.Input[bool] dnssec: Whether or not DNSSEC is enabled for the zone.
               Note that DNSSEC must be enabled on the account by support for this to be set
               to `true`.
        :param pulumi.Input[int] expiry: The SOA Expiry. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[str] hostmaster: (Computed) The SOA Hostmaster.
        :param pulumi.Input[str] link: The target zone(domain name) to link to.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] networks: List of network IDs for which the zone is
               available. If no network is provided, the zone will be created in network 0,
               the primary NS1 Global Network.
        :param pulumi.Input[int] nx_ttl: The SOA NX TTL. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[str] primary: The primary zones' IPv4 address. This makes the zone a
               secondary. Conflicts with `secondaries`.
        :param pulumi.Input[int] refresh: The SOA Refresh. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[int] retry: The SOA Retry. Conflicts with `primary` and
               `additional_primaries` (default must be accepted).
        :param pulumi.Input[Sequence[pulumi.Input[Union['ZoneSecondaryArgs', 'ZoneSecondaryArgsDict']]]] secondaries: List of secondary servers. This makes the zone a
               primary. Conflicts with `primary` and `additional_primaries`.
               Secondaries is documented below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: map of tags in the form of `"key" = "value"` where both key and value are strings
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tsig: TSIG is documented below
        :param pulumi.Input[int] ttl: The SOA TTL.
        :param pulumi.Input[str] zone: The domain name of the zone.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ZoneState.__new__(_ZoneState)

        __props__.__dict__["additional_ports"] = additional_ports
        __props__.__dict__["additional_primaries"] = additional_primaries
        __props__.__dict__["autogenerate_ns_record"] = autogenerate_ns_record
        __props__.__dict__["dns_servers"] = dns_servers
        __props__.__dict__["dnssec"] = dnssec
        __props__.__dict__["expiry"] = expiry
        __props__.__dict__["hostmaster"] = hostmaster
        __props__.__dict__["link"] = link
        __props__.__dict__["networks"] = networks
        __props__.__dict__["nx_ttl"] = nx_ttl
        __props__.__dict__["primary"] = primary
        __props__.__dict__["primary_port"] = primary_port
        __props__.__dict__["refresh"] = refresh
        __props__.__dict__["retry"] = retry
        __props__.__dict__["secondaries"] = secondaries
        __props__.__dict__["tags"] = tags
        __props__.__dict__["tsig"] = tsig
        __props__.__dict__["ttl"] = ttl
        __props__.__dict__["zone"] = zone
        return Zone(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="additionalPorts")
    def additional_ports(self) -> pulumi.Output[Optional[Sequence[int]]]:
        return pulumi.get(self, "additional_ports")

    @property
    @pulumi.getter(name="additionalPrimaries")
    def additional_primaries(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        List of additional IPv4 addresses for the primary
        zone. Conflicts with `secondaries`.
        """
        return pulumi.get(self, "additional_primaries")

    @property
    @pulumi.getter(name="autogenerateNsRecord")
    def autogenerate_ns_record(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "autogenerate_ns_record")

    @property
    @pulumi.getter(name="dnsServers")
    def dns_servers(self) -> pulumi.Output[str]:
        """
        (Computed) Authoritative Name Servers.
        """
        return pulumi.get(self, "dns_servers")

    @property
    @pulumi.getter
    def dnssec(self) -> pulumi.Output[bool]:
        """
        Whether or not DNSSEC is enabled for the zone.
        Note that DNSSEC must be enabled on the account by support for this to be set
        to `true`.
        """
        return pulumi.get(self, "dnssec")

    @property
    @pulumi.getter
    def expiry(self) -> pulumi.Output[int]:
        """
        The SOA Expiry. Conflicts with `primary` and
        `additional_primaries` (default must be accepted).
        """
        return pulumi.get(self, "expiry")

    @property
    @pulumi.getter
    def hostmaster(self) -> pulumi.Output[str]:
        """
        (Computed) The SOA Hostmaster.
        """
        return pulumi.get(self, "hostmaster")

    @property
    @pulumi.getter
    def link(self) -> pulumi.Output[Optional[str]]:
        """
        The target zone(domain name) to link to.
        """
        return pulumi.get(self, "link")

    @property
    @pulumi.getter
    def networks(self) -> pulumi.Output[Sequence[int]]:
        """
        List of network IDs for which the zone is
        available. If no network is provided, the zone will be created in network 0,
        the primary NS1 Global Network.
        """
        return pulumi.get(self, "networks")

    @property
    @pulumi.getter(name="nxTtl")
    def nx_ttl(self) -> pulumi.Output[int]:
        """
        The SOA NX TTL. Conflicts with `primary` and
        `additional_primaries` (default must be accepted).
        """
        return pulumi.get(self, "nx_ttl")

    @property
    @pulumi.getter
    def primary(self) -> pulumi.Output[Optional[str]]:
        """
        The primary zones' IPv4 address. This makes the zone a
        secondary. Conflicts with `secondaries`.
        """
        return pulumi.get(self, "primary")

    @property
    @pulumi.getter(name="primaryPort")
    def primary_port(self) -> pulumi.Output[int]:
        return pulumi.get(self, "primary_port")

    @property
    @pulumi.getter
    def refresh(self) -> pulumi.Output[int]:
        """
        The SOA Refresh. Conflicts with `primary` and
        `additional_primaries` (default must be accepted).
        """
        return pulumi.get(self, "refresh")

    @property
    @pulumi.getter
    def retry(self) -> pulumi.Output[int]:
        """
        The SOA Retry. Conflicts with `primary` and
        `additional_primaries` (default must be accepted).
        """
        return pulumi.get(self, "retry")

    @property
    @pulumi.getter
    def secondaries(self) -> pulumi.Output[Optional[Sequence['outputs.ZoneSecondary']]]:
        """
        List of secondary servers. This makes the zone a
        primary. Conflicts with `primary` and `additional_primaries`.
        Secondaries is documented below.
        """
        return pulumi.get(self, "secondaries")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        map of tags in the form of `"key" = "value"` where both key and value are strings
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def tsig(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        TSIG is documented below
        """
        return pulumi.get(self, "tsig")

    @property
    @pulumi.getter
    def ttl(self) -> pulumi.Output[int]:
        """
        The SOA TTL.
        """
        return pulumi.get(self, "ttl")

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Output[str]:
        """
        The domain name of the zone.
        """
        return pulumi.get(self, "zone")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetDNSSecResult',
    'AwaitableGetDNSSecResult',
    'get_dns_sec',
    'get_dns_sec_output',
]

@pulumi.output_type
class GetDNSSecResult:
    """
    A collection of values returned by getDNSSec.
    """
    def __init__(__self__, delegations=None, id=None, keys=None, zone=None):
        if delegations and not isinstance(delegations, list):
            raise TypeError("Expected argument 'delegations' to be a list")
        pulumi.set(__self__, "delegations", delegations)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if keys and not isinstance(keys, list):
            raise TypeError("Expected argument 'keys' to be a list")
        pulumi.set(__self__, "keys", keys)
        if zone and not isinstance(zone, str):
            raise TypeError("Expected argument 'zone' to be a str")
        pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter
    def delegations(self) -> Sequence['outputs.GetDNSSecDelegationResult']:
        """
        (Computed) - Delegation field is documented
        below.
        """
        return pulumi.get(self, "delegations")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def keys(self) -> Sequence['outputs.GetDNSSecKeyResult']:
        """
        (Computed) - Keys field is documented below.
        """
        return pulumi.get(self, "keys")

    @property
    @pulumi.getter
    def zone(self) -> str:
        return pulumi.get(self, "zone")


class AwaitableGetDNSSecResult(GetDNSSecResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDNSSecResult(
            delegations=self.delegations,
            id=self.id,
            keys=self.keys,
            zone=self.zone)


def get_dns_sec(zone: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDNSSecResult:
    """
    Provides DNSSEC details about a NS1 Zone.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ns1 as ns1

    # Get DNSSEC details about a NS1 Zone.
    example_zone = ns1.Zone("example",
        zone="terraform.example.io",
        dnssec=True)
    example = ns1.get_dns_sec_output(zone=example_zone.zone)
    ```


    :param str zone: The name of the zone to get DNSSEC details for.
    """
    __args__ = dict()
    __args__['zone'] = zone
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ns1:index/getDNSSec:getDNSSec', __args__, opts=opts, typ=GetDNSSecResult).value

    return AwaitableGetDNSSecResult(
        delegations=pulumi.get(__ret__, 'delegations'),
        id=pulumi.get(__ret__, 'id'),
        keys=pulumi.get(__ret__, 'keys'),
        zone=pulumi.get(__ret__, 'zone'))
def get_dns_sec_output(zone: Optional[pulumi.Input[str]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDNSSecResult]:
    """
    Provides DNSSEC details about a NS1 Zone.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ns1 as ns1

    # Get DNSSEC details about a NS1 Zone.
    example_zone = ns1.Zone("example",
        zone="terraform.example.io",
        dnssec=True)
    example = ns1.get_dns_sec_output(zone=example_zone.zone)
    ```


    :param str zone: The name of the zone to get DNSSEC details for.
    """
    __args__ = dict()
    __args__['zone'] = zone
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ns1:index/getDNSSec:getDNSSec', __args__, opts=opts, typ=GetDNSSecResult)
    return __ret__.apply(lambda __response__: GetDNSSecResult(
        delegations=pulumi.get(__response__, 'delegations'),
        id=pulumi.get(__response__, 'id'),
        keys=pulumi.get(__response__, 'keys'),
        zone=pulumi.get(__response__, 'zone')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TeamArgs', 'Team']

@pulumi.input_type
class TeamArgs:
    def __init__(__self__, *,
                 account_manage_account_settings: Optional[pulumi.Input[bool]] = None,
                 account_manage_apikeys: Optional[pulumi.Input[bool]] = None,
                 account_manage_ip_whitelist: Optional[pulumi.Input[bool]] = None,
                 account_manage_payment_methods: Optional[pulumi.Input[bool]] = None,
                 account_manage_plan: Optional[pulumi.Input[bool]] = None,
                 account_manage_teams: Optional[pulumi.Input[bool]] = None,
                 account_manage_users: Optional[pulumi.Input[bool]] = None,
                 account_view_activity_log: Optional[pulumi.Input[bool]] = None,
                 account_view_invoices: Optional[pulumi.Input[bool]] = None,
                 data_manage_datafeeds: Optional[pulumi.Input[bool]] = None,
                 data_manage_datasources: Optional[pulumi.Input[bool]] = None,
                 data_push_to_datafeeds: Optional[pulumi.Input[bool]] = None,
                 dns_manage_zones: Optional[pulumi.Input[bool]] = None,
                 dns_records_allows: Optional[pulumi.Input[Sequence[pulumi.Input['TeamDnsRecordsAllowArgs']]]] = None,
                 dns_records_denies: Optional[pulumi.Input[Sequence[pulumi.Input['TeamDnsRecordsDenyArgs']]]] = None,
                 dns_view_zones: Optional[pulumi.Input[bool]] = None,
                 dns_zones_allow_by_default: Optional[pulumi.Input[bool]] = None,
                 dns_zones_allows: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dns_zones_denies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 ip_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input['TeamIpWhitelistArgs']]]] = None,
                 monitoring_create_jobs: Optional[pulumi.Input[bool]] = None,
                 monitoring_delete_jobs: Optional[pulumi.Input[bool]] = None,
                 monitoring_manage_jobs: Optional[pulumi.Input[bool]] = None,
                 monitoring_manage_lists: Optional[pulumi.Input[bool]] = None,
                 monitoring_update_jobs: Optional[pulumi.Input[bool]] = None,
                 monitoring_view_jobs: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 security_manage_active_directory: Optional[pulumi.Input[bool]] = None,
                 security_manage_global2fa: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a Team resource.
        :param pulumi.Input[bool] account_manage_account_settings: Whether the team can modify account settings.
        :param pulumi.Input[bool] account_manage_apikeys: Whether the team can modify account apikeys.
        :param pulumi.Input[bool] account_manage_ip_whitelist: Whether the team can manage ip whitelist.
        :param pulumi.Input[bool] account_manage_payment_methods: Whether the team can modify account payment methods.
        :param pulumi.Input[bool] account_manage_plan: No longer in use.
        :param pulumi.Input[bool] account_manage_teams: Whether the team can modify other teams in the account.
        :param pulumi.Input[bool] account_manage_users: Whether the team can modify account users.
        :param pulumi.Input[bool] account_view_activity_log: Whether the team can view activity logs.
        :param pulumi.Input[bool] account_view_invoices: Whether the team can view invoices.
        :param pulumi.Input[bool] data_manage_datafeeds: Whether the team can modify data feeds.
        :param pulumi.Input[bool] data_manage_datasources: Whether the team can modify data sources.
        :param pulumi.Input[bool] data_push_to_datafeeds: Whether the team can publish to data feeds.
        :param pulumi.Input[bool] dns_manage_zones: Whether the team can modify the accounts zones.
        :param pulumi.Input[Sequence[pulumi.Input['TeamDnsRecordsAllowArgs']]] dns_records_allows: List of records that the team may access.
        :param pulumi.Input[Sequence[pulumi.Input['TeamDnsRecordsDenyArgs']]] dns_records_denies: List of records that the team may not access.
        :param pulumi.Input[bool] dns_view_zones: Whether the team can view the accounts zones.
        :param pulumi.Input[bool] dns_zones_allow_by_default: If true, enable the `dns_zones_allow` list, otherwise enable the `dns_zones_deny` list.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_zones_allows: List of zones that the team may access.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_zones_denies: List of zones that the team may not access.
        :param pulumi.Input[Sequence[pulumi.Input['TeamIpWhitelistArgs']]] ip_whitelists: Array of IP addresses objects to chich to grant the team access. Each object includes a **name** (string), and **values** (array of strings) associated to each "allow" list.
        :param pulumi.Input[bool] monitoring_create_jobs: Whether the user can create monitoring jobs when manage_jobs is not set to true.
        :param pulumi.Input[bool] monitoring_delete_jobs: Whether the user can delete monitoring jobs when manage_jobs is not set to true.
        :param pulumi.Input[bool] monitoring_manage_jobs: Whether the user can create, update, and delete monitoring jobs.
        :param pulumi.Input[bool] monitoring_manage_lists: Whether the team can modify notification lists.
        :param pulumi.Input[bool] monitoring_update_jobs: Whether the user can update monitoring jobs when manage_jobs is not set to true.
        :param pulumi.Input[bool] monitoring_view_jobs: Whether the team can view monitoring jobs.
        :param pulumi.Input[str] name: The free form name of the team.
        :param pulumi.Input[bool] security_manage_active_directory: Whether the team can manage global active directory.
               Only relevant for the DDI product.
        :param pulumi.Input[bool] security_manage_global2fa: Whether the team can manage global two factor authentication.
        """
        if account_manage_account_settings is not None:
            pulumi.set(__self__, "account_manage_account_settings", account_manage_account_settings)
        if account_manage_apikeys is not None:
            pulumi.set(__self__, "account_manage_apikeys", account_manage_apikeys)
        if account_manage_ip_whitelist is not None:
            pulumi.set(__self__, "account_manage_ip_whitelist", account_manage_ip_whitelist)
        if account_manage_payment_methods is not None:
            pulumi.set(__self__, "account_manage_payment_methods", account_manage_payment_methods)
        if account_manage_plan is not None:
            warnings.warn("""obsolete, should no longer be used""", DeprecationWarning)
            pulumi.log.warn("""account_manage_plan is deprecated: obsolete, should no longer be used""")
        if account_manage_plan is not None:
            pulumi.set(__self__, "account_manage_plan", account_manage_plan)
        if account_manage_teams is not None:
            pulumi.set(__self__, "account_manage_teams", account_manage_teams)
        if account_manage_users is not None:
            pulumi.set(__self__, "account_manage_users", account_manage_users)
        if account_view_activity_log is not None:
            pulumi.set(__self__, "account_view_activity_log", account_view_activity_log)
        if account_view_invoices is not None:
            pulumi.set(__self__, "account_view_invoices", account_view_invoices)
        if data_manage_datafeeds is not None:
            pulumi.set(__self__, "data_manage_datafeeds", data_manage_datafeeds)
        if data_manage_datasources is not None:
            pulumi.set(__self__, "data_manage_datasources", data_manage_datasources)
        if data_push_to_datafeeds is not None:
            pulumi.set(__self__, "data_push_to_datafeeds", data_push_to_datafeeds)
        if dns_manage_zones is not None:
            pulumi.set(__self__, "dns_manage_zones", dns_manage_zones)
        if dns_records_allows is not None:
            pulumi.set(__self__, "dns_records_allows", dns_records_allows)
        if dns_records_denies is not None:
            pulumi.set(__self__, "dns_records_denies", dns_records_denies)
        if dns_view_zones is not None:
            pulumi.set(__self__, "dns_view_zones", dns_view_zones)
        if dns_zones_allow_by_default is not None:
            pulumi.set(__self__, "dns_zones_allow_by_default", dns_zones_allow_by_default)
        if dns_zones_allows is not None:
            pulumi.set(__self__, "dns_zones_allows", dns_zones_allows)
        if dns_zones_denies is not None:
            pulumi.set(__self__, "dns_zones_denies", dns_zones_denies)
        if ip_whitelists is not None:
            pulumi.set(__self__, "ip_whitelists", ip_whitelists)
        if monitoring_create_jobs is not None:
            pulumi.set(__self__, "monitoring_create_jobs", monitoring_create_jobs)
        if monitoring_delete_jobs is not None:
            pulumi.set(__self__, "monitoring_delete_jobs", monitoring_delete_jobs)
        if monitoring_manage_jobs is not None:
            pulumi.set(__self__, "monitoring_manage_jobs", monitoring_manage_jobs)
        if monitoring_manage_lists is not None:
            pulumi.set(__self__, "monitoring_manage_lists", monitoring_manage_lists)
        if monitoring_update_jobs is not None:
            pulumi.set(__self__, "monitoring_update_jobs", monitoring_update_jobs)
        if monitoring_view_jobs is not None:
            pulumi.set(__self__, "monitoring_view_jobs", monitoring_view_jobs)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if security_manage_active_directory is not None:
            pulumi.set(__self__, "security_manage_active_directory", security_manage_active_directory)
        if security_manage_global2fa is not None:
            pulumi.set(__self__, "security_manage_global2fa", security_manage_global2fa)

    @property
    @pulumi.getter(name="accountManageAccountSettings")
    def account_manage_account_settings(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify account settings.
        """
        return pulumi.get(self, "account_manage_account_settings")

    @account_manage_account_settings.setter
    def account_manage_account_settings(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_manage_account_settings", value)

    @property
    @pulumi.getter(name="accountManageApikeys")
    def account_manage_apikeys(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify account apikeys.
        """
        return pulumi.get(self, "account_manage_apikeys")

    @account_manage_apikeys.setter
    def account_manage_apikeys(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_manage_apikeys", value)

    @property
    @pulumi.getter(name="accountManageIpWhitelist")
    def account_manage_ip_whitelist(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can manage ip whitelist.
        """
        return pulumi.get(self, "account_manage_ip_whitelist")

    @account_manage_ip_whitelist.setter
    def account_manage_ip_whitelist(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_manage_ip_whitelist", value)

    @property
    @pulumi.getter(name="accountManagePaymentMethods")
    def account_manage_payment_methods(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify account payment methods.
        """
        return pulumi.get(self, "account_manage_payment_methods")

    @account_manage_payment_methods.setter
    def account_manage_payment_methods(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_manage_payment_methods", value)

    @property
    @pulumi.getter(name="accountManagePlan")
    @_utilities.deprecated("""obsolete, should no longer be used""")
    def account_manage_plan(self) -> Optional[pulumi.Input[bool]]:
        """
        No longer in use.
        """
        return pulumi.get(self, "account_manage_plan")

    @account_manage_plan.setter
    def account_manage_plan(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_manage_plan", value)

    @property
    @pulumi.getter(name="accountManageTeams")
    def account_manage_teams(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify other teams in the account.
        """
        return pulumi.get(self, "account_manage_teams")

    @account_manage_teams.setter
    def account_manage_teams(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_manage_teams", value)

    @property
    @pulumi.getter(name="accountManageUsers")
    def account_manage_users(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify account users.
        """
        return pulumi.get(self, "account_manage_users")

    @account_manage_users.setter
    def account_manage_users(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_manage_users", value)

    @property
    @pulumi.getter(name="accountViewActivityLog")
    def account_view_activity_log(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can view activity logs.
        """
        return pulumi.get(self, "account_view_activity_log")

    @account_view_activity_log.setter
    def account_view_activity_log(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_view_activity_log", value)

    @property
    @pulumi.getter(name="accountViewInvoices")
    def account_view_invoices(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can view invoices.
        """
        return pulumi.get(self, "account_view_invoices")

    @account_view_invoices.setter
    def account_view_invoices(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_view_invoices", value)

    @property
    @pulumi.getter(name="dataManageDatafeeds")
    def data_manage_datafeeds(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify data feeds.
        """
        return pulumi.get(self, "data_manage_datafeeds")

    @data_manage_datafeeds.setter
    def data_manage_datafeeds(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "data_manage_datafeeds", value)

    @property
    @pulumi.getter(name="dataManageDatasources")
    def data_manage_datasources(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify data sources.
        """
        return pulumi.get(self, "data_manage_datasources")

    @data_manage_datasources.setter
    def data_manage_datasources(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "data_manage_datasources", value)

    @property
    @pulumi.getter(name="dataPushToDatafeeds")
    def data_push_to_datafeeds(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can publish to data feeds.
        """
        return pulumi.get(self, "data_push_to_datafeeds")

    @data_push_to_datafeeds.setter
    def data_push_to_datafeeds(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "data_push_to_datafeeds", value)

    @property
    @pulumi.getter(name="dnsManageZones")
    def dns_manage_zones(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify the accounts zones.
        """
        return pulumi.get(self, "dns_manage_zones")

    @dns_manage_zones.setter
    def dns_manage_zones(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dns_manage_zones", value)

    @property
    @pulumi.getter(name="dnsRecordsAllows")
    def dns_records_allows(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TeamDnsRecordsAllowArgs']]]]:
        """
        List of records that the team may access.
        """
        return pulumi.get(self, "dns_records_allows")

    @dns_records_allows.setter
    def dns_records_allows(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TeamDnsRecordsAllowArgs']]]]):
        pulumi.set(self, "dns_records_allows", value)

    @property
    @pulumi.getter(name="dnsRecordsDenies")
    def dns_records_denies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TeamDnsRecordsDenyArgs']]]]:
        """
        List of records that the team may not access.
        """
        return pulumi.get(self, "dns_records_denies")

    @dns_records_denies.setter
    def dns_records_denies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TeamDnsRecordsDenyArgs']]]]):
        pulumi.set(self, "dns_records_denies", value)

    @property
    @pulumi.getter(name="dnsViewZones")
    def dns_view_zones(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can view the accounts zones.
        """
        return pulumi.get(self, "dns_view_zones")

    @dns_view_zones.setter
    def dns_view_zones(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dns_view_zones", value)

    @property
    @pulumi.getter(name="dnsZonesAllowByDefault")
    def dns_zones_allow_by_default(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, enable the `dns_zones_allow` list, otherwise enable the `dns_zones_deny` list.
        """
        return pulumi.get(self, "dns_zones_allow_by_default")

    @dns_zones_allow_by_default.setter
    def dns_zones_allow_by_default(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dns_zones_allow_by_default", value)

    @property
    @pulumi.getter(name="dnsZonesAllows")
    def dns_zones_allows(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of zones that the team may access.
        """
        return pulumi.get(self, "dns_zones_allows")

    @dns_zones_allows.setter
    def dns_zones_allows(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "dns_zones_allows", value)

    @property
    @pulumi.getter(name="dnsZonesDenies")
    def dns_zones_denies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of zones that the team may not access.
        """
        return pulumi.get(self, "dns_zones_denies")

    @dns_zones_denies.setter
    def dns_zones_denies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "dns_zones_denies", value)

    @property
    @pulumi.getter(name="ipWhitelists")
    def ip_whitelists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TeamIpWhitelistArgs']]]]:
        """
        Array of IP addresses objects to chich to grant the team access. Each object includes a **name** (string), and **values** (array of strings) associated to each "allow" list.
        """
        return pulumi.get(self, "ip_whitelists")

    @ip_whitelists.setter
    def ip_whitelists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TeamIpWhitelistArgs']]]]):
        pulumi.set(self, "ip_whitelists", value)

    @property
    @pulumi.getter(name="monitoringCreateJobs")
    def monitoring_create_jobs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the user can create monitoring jobs when manage_jobs is not set to true.
        """
        return pulumi.get(self, "monitoring_create_jobs")

    @monitoring_create_jobs.setter
    def monitoring_create_jobs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "monitoring_create_jobs", value)

    @property
    @pulumi.getter(name="monitoringDeleteJobs")
    def monitoring_delete_jobs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the user can delete monitoring jobs when manage_jobs is not set to true.
        """
        return pulumi.get(self, "monitoring_delete_jobs")

    @monitoring_delete_jobs.setter
    def monitoring_delete_jobs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "monitoring_delete_jobs", value)

    @property
    @pulumi.getter(name="monitoringManageJobs")
    def monitoring_manage_jobs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the user can create, update, and delete monitoring jobs.
        """
        return pulumi.get(self, "monitoring_manage_jobs")

    @monitoring_manage_jobs.setter
    def monitoring_manage_jobs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "monitoring_manage_jobs", value)

    @property
    @pulumi.getter(name="monitoringManageLists")
    def monitoring_manage_lists(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify notification lists.
        """
        return pulumi.get(self, "monitoring_manage_lists")

    @monitoring_manage_lists.setter
    def monitoring_manage_lists(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "monitoring_manage_lists", value)

    @property
    @pulumi.getter(name="monitoringUpdateJobs")
    def monitoring_update_jobs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the user can update monitoring jobs when manage_jobs is not set to true.
        """
        return pulumi.get(self, "monitoring_update_jobs")

    @monitoring_update_jobs.setter
    def monitoring_update_jobs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "monitoring_update_jobs", value)

    @property
    @pulumi.getter(name="monitoringViewJobs")
    def monitoring_view_jobs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can view monitoring jobs.
        """
        return pulumi.get(self, "monitoring_view_jobs")

    @monitoring_view_jobs.setter
    def monitoring_view_jobs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "monitoring_view_jobs", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The free form name of the team.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="securityManageActiveDirectory")
    def security_manage_active_directory(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can manage global active directory.
        Only relevant for the DDI product.
        """
        return pulumi.get(self, "security_manage_active_directory")

    @security_manage_active_directory.setter
    def security_manage_active_directory(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "security_manage_active_directory", value)

    @property
    @pulumi.getter(name="securityManageGlobal2fa")
    def security_manage_global2fa(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can manage global two factor authentication.
        """
        return pulumi.get(self, "security_manage_global2fa")

    @security_manage_global2fa.setter
    def security_manage_global2fa(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "security_manage_global2fa", value)


@pulumi.input_type
class _TeamState:
    def __init__(__self__, *,
                 account_manage_account_settings: Optional[pulumi.Input[bool]] = None,
                 account_manage_apikeys: Optional[pulumi.Input[bool]] = None,
                 account_manage_ip_whitelist: Optional[pulumi.Input[bool]] = None,
                 account_manage_payment_methods: Optional[pulumi.Input[bool]] = None,
                 account_manage_plan: Optional[pulumi.Input[bool]] = None,
                 account_manage_teams: Optional[pulumi.Input[bool]] = None,
                 account_manage_users: Optional[pulumi.Input[bool]] = None,
                 account_view_activity_log: Optional[pulumi.Input[bool]] = None,
                 account_view_invoices: Optional[pulumi.Input[bool]] = None,
                 data_manage_datafeeds: Optional[pulumi.Input[bool]] = None,
                 data_manage_datasources: Optional[pulumi.Input[bool]] = None,
                 data_push_to_datafeeds: Optional[pulumi.Input[bool]] = None,
                 dns_manage_zones: Optional[pulumi.Input[bool]] = None,
                 dns_records_allows: Optional[pulumi.Input[Sequence[pulumi.Input['TeamDnsRecordsAllowArgs']]]] = None,
                 dns_records_denies: Optional[pulumi.Input[Sequence[pulumi.Input['TeamDnsRecordsDenyArgs']]]] = None,
                 dns_view_zones: Optional[pulumi.Input[bool]] = None,
                 dns_zones_allow_by_default: Optional[pulumi.Input[bool]] = None,
                 dns_zones_allows: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dns_zones_denies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 ip_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input['TeamIpWhitelistArgs']]]] = None,
                 monitoring_create_jobs: Optional[pulumi.Input[bool]] = None,
                 monitoring_delete_jobs: Optional[pulumi.Input[bool]] = None,
                 monitoring_manage_jobs: Optional[pulumi.Input[bool]] = None,
                 monitoring_manage_lists: Optional[pulumi.Input[bool]] = None,
                 monitoring_update_jobs: Optional[pulumi.Input[bool]] = None,
                 monitoring_view_jobs: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 security_manage_active_directory: Optional[pulumi.Input[bool]] = None,
                 security_manage_global2fa: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering Team resources.
        :param pulumi.Input[bool] account_manage_account_settings: Whether the team can modify account settings.
        :param pulumi.Input[bool] account_manage_apikeys: Whether the team can modify account apikeys.
        :param pulumi.Input[bool] account_manage_ip_whitelist: Whether the team can manage ip whitelist.
        :param pulumi.Input[bool] account_manage_payment_methods: Whether the team can modify account payment methods.
        :param pulumi.Input[bool] account_manage_plan: No longer in use.
        :param pulumi.Input[bool] account_manage_teams: Whether the team can modify other teams in the account.
        :param pulumi.Input[bool] account_manage_users: Whether the team can modify account users.
        :param pulumi.Input[bool] account_view_activity_log: Whether the team can view activity logs.
        :param pulumi.Input[bool] account_view_invoices: Whether the team can view invoices.
        :param pulumi.Input[bool] data_manage_datafeeds: Whether the team can modify data feeds.
        :param pulumi.Input[bool] data_manage_datasources: Whether the team can modify data sources.
        :param pulumi.Input[bool] data_push_to_datafeeds: Whether the team can publish to data feeds.
        :param pulumi.Input[bool] dns_manage_zones: Whether the team can modify the accounts zones.
        :param pulumi.Input[Sequence[pulumi.Input['TeamDnsRecordsAllowArgs']]] dns_records_allows: List of records that the team may access.
        :param pulumi.Input[Sequence[pulumi.Input['TeamDnsRecordsDenyArgs']]] dns_records_denies: List of records that the team may not access.
        :param pulumi.Input[bool] dns_view_zones: Whether the team can view the accounts zones.
        :param pulumi.Input[bool] dns_zones_allow_by_default: If true, enable the `dns_zones_allow` list, otherwise enable the `dns_zones_deny` list.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_zones_allows: List of zones that the team may access.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_zones_denies: List of zones that the team may not access.
        :param pulumi.Input[Sequence[pulumi.Input['TeamIpWhitelistArgs']]] ip_whitelists: Array of IP addresses objects to chich to grant the team access. Each object includes a **name** (string), and **values** (array of strings) associated to each "allow" list.
        :param pulumi.Input[bool] monitoring_create_jobs: Whether the user can create monitoring jobs when manage_jobs is not set to true.
        :param pulumi.Input[bool] monitoring_delete_jobs: Whether the user can delete monitoring jobs when manage_jobs is not set to true.
        :param pulumi.Input[bool] monitoring_manage_jobs: Whether the user can create, update, and delete monitoring jobs.
        :param pulumi.Input[bool] monitoring_manage_lists: Whether the team can modify notification lists.
        :param pulumi.Input[bool] monitoring_update_jobs: Whether the user can update monitoring jobs when manage_jobs is not set to true.
        :param pulumi.Input[bool] monitoring_view_jobs: Whether the team can view monitoring jobs.
        :param pulumi.Input[str] name: The free form name of the team.
        :param pulumi.Input[bool] security_manage_active_directory: Whether the team can manage global active directory.
               Only relevant for the DDI product.
        :param pulumi.Input[bool] security_manage_global2fa: Whether the team can manage global two factor authentication.
        """
        if account_manage_account_settings is not None:
            pulumi.set(__self__, "account_manage_account_settings", account_manage_account_settings)
        if account_manage_apikeys is not None:
            pulumi.set(__self__, "account_manage_apikeys", account_manage_apikeys)
        if account_manage_ip_whitelist is not None:
            pulumi.set(__self__, "account_manage_ip_whitelist", account_manage_ip_whitelist)
        if account_manage_payment_methods is not None:
            pulumi.set(__self__, "account_manage_payment_methods", account_manage_payment_methods)
        if account_manage_plan is not None:
            warnings.warn("""obsolete, should no longer be used""", DeprecationWarning)
            pulumi.log.warn("""account_manage_plan is deprecated: obsolete, should no longer be used""")
        if account_manage_plan is not None:
            pulumi.set(__self__, "account_manage_plan", account_manage_plan)
        if account_manage_teams is not None:
            pulumi.set(__self__, "account_manage_teams", account_manage_teams)
        if account_manage_users is not None:
            pulumi.set(__self__, "account_manage_users", account_manage_users)
        if account_view_activity_log is not None:
            pulumi.set(__self__, "account_view_activity_log", account_view_activity_log)
        if account_view_invoices is not None:
            pulumi.set(__self__, "account_view_invoices", account_view_invoices)
        if data_manage_datafeeds is not None:
            pulumi.set(__self__, "data_manage_datafeeds", data_manage_datafeeds)
        if data_manage_datasources is not None:
            pulumi.set(__self__, "data_manage_datasources", data_manage_datasources)
        if data_push_to_datafeeds is not None:
            pulumi.set(__self__, "data_push_to_datafeeds", data_push_to_datafeeds)
        if dns_manage_zones is not None:
            pulumi.set(__self__, "dns_manage_zones", dns_manage_zones)
        if dns_records_allows is not None:
            pulumi.set(__self__, "dns_records_allows", dns_records_allows)
        if dns_records_denies is not None:
            pulumi.set(__self__, "dns_records_denies", dns_records_denies)
        if dns_view_zones is not None:
            pulumi.set(__self__, "dns_view_zones", dns_view_zones)
        if dns_zones_allow_by_default is not None:
            pulumi.set(__self__, "dns_zones_allow_by_default", dns_zones_allow_by_default)
        if dns_zones_allows is not None:
            pulumi.set(__self__, "dns_zones_allows", dns_zones_allows)
        if dns_zones_denies is not None:
            pulumi.set(__self__, "dns_zones_denies", dns_zones_denies)
        if ip_whitelists is not None:
            pulumi.set(__self__, "ip_whitelists", ip_whitelists)
        if monitoring_create_jobs is not None:
            pulumi.set(__self__, "monitoring_create_jobs", monitoring_create_jobs)
        if monitoring_delete_jobs is not None:
            pulumi.set(__self__, "monitoring_delete_jobs", monitoring_delete_jobs)
        if monitoring_manage_jobs is not None:
            pulumi.set(__self__, "monitoring_manage_jobs", monitoring_manage_jobs)
        if monitoring_manage_lists is not None:
            pulumi.set(__self__, "monitoring_manage_lists", monitoring_manage_lists)
        if monitoring_update_jobs is not None:
            pulumi.set(__self__, "monitoring_update_jobs", monitoring_update_jobs)
        if monitoring_view_jobs is not None:
            pulumi.set(__self__, "monitoring_view_jobs", monitoring_view_jobs)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if security_manage_active_directory is not None:
            pulumi.set(__self__, "security_manage_active_directory", security_manage_active_directory)
        if security_manage_global2fa is not None:
            pulumi.set(__self__, "security_manage_global2fa", security_manage_global2fa)

    @property
    @pulumi.getter(name="accountManageAccountSettings")
    def account_manage_account_settings(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify account settings.
        """
        return pulumi.get(self, "account_manage_account_settings")

    @account_manage_account_settings.setter
    def account_manage_account_settings(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_manage_account_settings", value)

    @property
    @pulumi.getter(name="accountManageApikeys")
    def account_manage_apikeys(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify account apikeys.
        """
        return pulumi.get(self, "account_manage_apikeys")

    @account_manage_apikeys.setter
    def account_manage_apikeys(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_manage_apikeys", value)

    @property
    @pulumi.getter(name="accountManageIpWhitelist")
    def account_manage_ip_whitelist(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can manage ip whitelist.
        """
        return pulumi.get(self, "account_manage_ip_whitelist")

    @account_manage_ip_whitelist.setter
    def account_manage_ip_whitelist(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_manage_ip_whitelist", value)

    @property
    @pulumi.getter(name="accountManagePaymentMethods")
    def account_manage_payment_methods(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify account payment methods.
        """
        return pulumi.get(self, "account_manage_payment_methods")

    @account_manage_payment_methods.setter
    def account_manage_payment_methods(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_manage_payment_methods", value)

    @property
    @pulumi.getter(name="accountManagePlan")
    @_utilities.deprecated("""obsolete, should no longer be used""")
    def account_manage_plan(self) -> Optional[pulumi.Input[bool]]:
        """
        No longer in use.
        """
        return pulumi.get(self, "account_manage_plan")

    @account_manage_plan.setter
    def account_manage_plan(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_manage_plan", value)

    @property
    @pulumi.getter(name="accountManageTeams")
    def account_manage_teams(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify other teams in the account.
        """
        return pulumi.get(self, "account_manage_teams")

    @account_manage_teams.setter
    def account_manage_teams(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_manage_teams", value)

    @property
    @pulumi.getter(name="accountManageUsers")
    def account_manage_users(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify account users.
        """
        return pulumi.get(self, "account_manage_users")

    @account_manage_users.setter
    def account_manage_users(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_manage_users", value)

    @property
    @pulumi.getter(name="accountViewActivityLog")
    def account_view_activity_log(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can view activity logs.
        """
        return pulumi.get(self, "account_view_activity_log")

    @account_view_activity_log.setter
    def account_view_activity_log(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_view_activity_log", value)

    @property
    @pulumi.getter(name="accountViewInvoices")
    def account_view_invoices(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can view invoices.
        """
        return pulumi.get(self, "account_view_invoices")

    @account_view_invoices.setter
    def account_view_invoices(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "account_view_invoices", value)

    @property
    @pulumi.getter(name="dataManageDatafeeds")
    def data_manage_datafeeds(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify data feeds.
        """
        return pulumi.get(self, "data_manage_datafeeds")

    @data_manage_datafeeds.setter
    def data_manage_datafeeds(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "data_manage_datafeeds", value)

    @property
    @pulumi.getter(name="dataManageDatasources")
    def data_manage_datasources(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify data sources.
        """
        return pulumi.get(self, "data_manage_datasources")

    @data_manage_datasources.setter
    def data_manage_datasources(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "data_manage_datasources", value)

    @property
    @pulumi.getter(name="dataPushToDatafeeds")
    def data_push_to_datafeeds(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can publish to data feeds.
        """
        return pulumi.get(self, "data_push_to_datafeeds")

    @data_push_to_datafeeds.setter
    def data_push_to_datafeeds(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "data_push_to_datafeeds", value)

    @property
    @pulumi.getter(name="dnsManageZones")
    def dns_manage_zones(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify the accounts zones.
        """
        return pulumi.get(self, "dns_manage_zones")

    @dns_manage_zones.setter
    def dns_manage_zones(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dns_manage_zones", value)

    @property
    @pulumi.getter(name="dnsRecordsAllows")
    def dns_records_allows(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TeamDnsRecordsAllowArgs']]]]:
        """
        List of records that the team may access.
        """
        return pulumi.get(self, "dns_records_allows")

    @dns_records_allows.setter
    def dns_records_allows(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TeamDnsRecordsAllowArgs']]]]):
        pulumi.set(self, "dns_records_allows", value)

    @property
    @pulumi.getter(name="dnsRecordsDenies")
    def dns_records_denies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TeamDnsRecordsDenyArgs']]]]:
        """
        List of records that the team may not access.
        """
        return pulumi.get(self, "dns_records_denies")

    @dns_records_denies.setter
    def dns_records_denies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TeamDnsRecordsDenyArgs']]]]):
        pulumi.set(self, "dns_records_denies", value)

    @property
    @pulumi.getter(name="dnsViewZones")
    def dns_view_zones(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can view the accounts zones.
        """
        return pulumi.get(self, "dns_view_zones")

    @dns_view_zones.setter
    def dns_view_zones(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dns_view_zones", value)

    @property
    @pulumi.getter(name="dnsZonesAllowByDefault")
    def dns_zones_allow_by_default(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, enable the `dns_zones_allow` list, otherwise enable the `dns_zones_deny` list.
        """
        return pulumi.get(self, "dns_zones_allow_by_default")

    @dns_zones_allow_by_default.setter
    def dns_zones_allow_by_default(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dns_zones_allow_by_default", value)

    @property
    @pulumi.getter(name="dnsZonesAllows")
    def dns_zones_allows(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of zones that the team may access.
        """
        return pulumi.get(self, "dns_zones_allows")

    @dns_zones_allows.setter
    def dns_zones_allows(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "dns_zones_allows", value)

    @property
    @pulumi.getter(name="dnsZonesDenies")
    def dns_zones_denies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of zones that the team may not access.
        """
        return pulumi.get(self, "dns_zones_denies")

    @dns_zones_denies.setter
    def dns_zones_denies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "dns_zones_denies", value)

    @property
    @pulumi.getter(name="ipWhitelists")
    def ip_whitelists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TeamIpWhitelistArgs']]]]:
        """
        Array of IP addresses objects to chich to grant the team access. Each object includes a **name** (string), and **values** (array of strings) associated to each "allow" list.
        """
        return pulumi.get(self, "ip_whitelists")

    @ip_whitelists.setter
    def ip_whitelists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TeamIpWhitelistArgs']]]]):
        pulumi.set(self, "ip_whitelists", value)

    @property
    @pulumi.getter(name="monitoringCreateJobs")
    def monitoring_create_jobs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the user can create monitoring jobs when manage_jobs is not set to true.
        """
        return pulumi.get(self, "monitoring_create_jobs")

    @monitoring_create_jobs.setter
    def monitoring_create_jobs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "monitoring_create_jobs", value)

    @property
    @pulumi.getter(name="monitoringDeleteJobs")
    def monitoring_delete_jobs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the user can delete monitoring jobs when manage_jobs is not set to true.
        """
        return pulumi.get(self, "monitoring_delete_jobs")

    @monitoring_delete_jobs.setter
    def monitoring_delete_jobs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "monitoring_delete_jobs", value)

    @property
    @pulumi.getter(name="monitoringManageJobs")
    def monitoring_manage_jobs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the user can create, update, and delete monitoring jobs.
        """
        return pulumi.get(self, "monitoring_manage_jobs")

    @monitoring_manage_jobs.setter
    def monitoring_manage_jobs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "monitoring_manage_jobs", value)

    @property
    @pulumi.getter(name="monitoringManageLists")
    def monitoring_manage_lists(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can modify notification lists.
        """
        return pulumi.get(self, "monitoring_manage_lists")

    @monitoring_manage_lists.setter
    def monitoring_manage_lists(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "monitoring_manage_lists", value)

    @property
    @pulumi.getter(name="monitoringUpdateJobs")
    def monitoring_update_jobs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the user can update monitoring jobs when manage_jobs is not set to true.
        """
        return pulumi.get(self, "monitoring_update_jobs")

    @monitoring_update_jobs.setter
    def monitoring_update_jobs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "monitoring_update_jobs", value)

    @property
    @pulumi.getter(name="monitoringViewJobs")
    def monitoring_view_jobs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can view monitoring jobs.
        """
        return pulumi.get(self, "monitoring_view_jobs")

    @monitoring_view_jobs.setter
    def monitoring_view_jobs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "monitoring_view_jobs", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The free form name of the team.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="securityManageActiveDirectory")
    def security_manage_active_directory(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can manage global active directory.
        Only relevant for the DDI product.
        """
        return pulumi.get(self, "security_manage_active_directory")

    @security_manage_active_directory.setter
    def security_manage_active_directory(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "security_manage_active_directory", value)

    @property
    @pulumi.getter(name="securityManageGlobal2fa")
    def security_manage_global2fa(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the team can manage global two factor authentication.
        """
        return pulumi.get(self, "security_manage_global2fa")

    @security_manage_global2fa.setter
    def security_manage_global2fa(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "security_manage_global2fa", value)


class Team(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_manage_account_settings: Optional[pulumi.Input[bool]] = None,
                 account_manage_apikeys: Optional[pulumi.Input[bool]] = None,
                 account_manage_ip_whitelist: Optional[pulumi.Input[bool]] = None,
                 account_manage_payment_methods: Optional[pulumi.Input[bool]] = None,
                 account_manage_plan: Optional[pulumi.Input[bool]] = None,
                 account_manage_teams: Optional[pulumi.Input[bool]] = None,
                 account_manage_users: Optional[pulumi.Input[bool]] = None,
                 account_view_activity_log: Optional[pulumi.Input[bool]] = None,
                 account_view_invoices: Optional[pulumi.Input[bool]] = None,
                 data_manage_datafeeds: Optional[pulumi.Input[bool]] = None,
                 data_manage_datasources: Optional[pulumi.Input[bool]] = None,
                 data_push_to_datafeeds: Optional[pulumi.Input[bool]] = None,
                 dns_manage_zones: Optional[pulumi.Input[bool]] = None,
                 dns_records_allows: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TeamDnsRecordsAllowArgs', 'TeamDnsRecordsAllowArgsDict']]]]] = None,
                 dns_records_denies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TeamDnsRecordsDenyArgs', 'TeamDnsRecordsDenyArgsDict']]]]] = None,
                 dns_view_zones: Optional[pulumi.Input[bool]] = None,
                 dns_zones_allow_by_default: Optional[pulumi.Input[bool]] = None,
                 dns_zones_allows: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dns_zones_denies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 ip_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TeamIpWhitelistArgs', 'TeamIpWhitelistArgsDict']]]]] = None,
                 monitoring_create_jobs: Optional[pulumi.Input[bool]] = None,
                 monitoring_delete_jobs: Optional[pulumi.Input[bool]] = None,
                 monitoring_manage_jobs: Optional[pulumi.Input[bool]] = None,
                 monitoring_manage_lists: Optional[pulumi.Input[bool]] = None,
                 monitoring_update_jobs: Optional[pulumi.Input[bool]] = None,
                 monitoring_view_jobs: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 security_manage_active_directory: Optional[pulumi.Input[bool]] = None,
                 security_manage_global2fa: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        Provides a NS1 Team resource. This can be used to create, modify, and delete
        teams. The credentials used must have the `manage_teams` permission set.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ns1 as ns1

        # Create a new NS1 Team
        example = ns1.Team("example",
            name="Example team",
            ip_whitelists=[
                {
                    "name": "whitelist-1",
                    "values": [
                        "1.1.1.1",
                        "2.2.2.2",
                    ],
                },
                {
                    "name": "whitelist-2",
                    "values": [
                        "3.3.3.3",
                        "4.4.4.4",
                    ],
                },
            ],
            dns_view_zones=False,
            account_manage_users=False)
        # Another team
        example2 = ns1.Team("example2",
            name="another team",
            dns_view_zones=True,
            dns_zones_allow_by_default=True,
            dns_zones_allows=["mytest.zone"],
            dns_zones_denies=["myother.zone"],
            dns_records_allows=[{
                "domain": "terraform.example.io",
                "include_subdomains": False,
                "zone": "example.io",
                "type": "A",
            }],
            data_manage_datasources=True)
        ```

        ## NS1 Documentation

        [Team Api Docs](https://ns1.com/api#team)

        ## Import

        ```sh
        $ pulumi import ns1:index/team:Team <name> <team_id>`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] account_manage_account_settings: Whether the team can modify account settings.
        :param pulumi.Input[bool] account_manage_apikeys: Whether the team can modify account apikeys.
        :param pulumi.Input[bool] account_manage_ip_whitelist: Whether the team can manage ip whitelist.
        :param pulumi.Input[bool] account_manage_payment_methods: Whether the team can modify account payment methods.
        :param pulumi.Input[bool] account_manage_plan: No longer in use.
        :param pulumi.Input[bool] account_manage_teams: Whether the team can modify other teams in the account.
        :param pulumi.Input[bool] account_manage_users: Whether the team can modify account users.
        :param pulumi.Input[bool] account_view_activity_log: Whether the team can view activity logs.
        :param pulumi.Input[bool] account_view_invoices: Whether the team can view invoices.
        :param pulumi.Input[bool] data_manage_datafeeds: Whether the team can modify data feeds.
        :param pulumi.Input[bool] data_manage_datasources: Whether the team can modify data sources.
        :param pulumi.Input[bool] data_push_to_datafeeds: Whether the team can publish to data feeds.
        :param pulumi.Input[bool] dns_manage_zones: Whether the team can modify the accounts zones.
        :param pulumi.Input[Sequence[pulumi.Input[Union['TeamDnsRecordsAllowArgs', 'TeamDnsRecordsAllowArgsDict']]]] dns_records_allows: List of records that the team may access.
        :param pulumi.Input[Sequence[pulumi.Input[Union['TeamDnsRecordsDenyArgs', 'TeamDnsRecordsDenyArgsDict']]]] dns_records_denies: List of records that the team may not access.
        :param pulumi.Input[bool] dns_view_zones: Whether the team can view the accounts zones.
        :param pulumi.Input[bool] dns_zones_allow_by_default: If true, enable the `dns_zones_allow` list, otherwise enable the `dns_zones_deny` list.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_zones_allows: List of zones that the team may access.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_zones_denies: List of zones that the team may not access.
        :param pulumi.Input[Sequence[pulumi.Input[Union['TeamIpWhitelistArgs', 'TeamIpWhitelistArgsDict']]]] ip_whitelists: Array of IP addresses objects to chich to grant the team access. Each object includes a **name** (string), and **values** (array of strings) associated to each "allow" list.
        :param pulumi.Input[bool] monitoring_create_jobs: Whether the user can create monitoring jobs when manage_jobs is not set to true.
        :param pulumi.Input[bool] monitoring_delete_jobs: Whether the user can delete monitoring jobs when manage_jobs is not set to true.
        :param pulumi.Input[bool] monitoring_manage_jobs: Whether the user can create, update, and delete monitoring jobs.
        :param pulumi.Input[bool] monitoring_manage_lists: Whether the team can modify notification lists.
        :param pulumi.Input[bool] monitoring_update_jobs: Whether the user can update monitoring jobs when manage_jobs is not set to true.
        :param pulumi.Input[bool] monitoring_view_jobs: Whether the team can view monitoring jobs.
        :param pulumi.Input[str] name: The free form name of the team.
        :param pulumi.Input[bool] security_manage_active_directory: Whether the team can manage global active directory.
               Only relevant for the DDI product.
        :param pulumi.Input[bool] security_manage_global2fa: Whether the team can manage global two factor authentication.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[TeamArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a NS1 Team resource. This can be used to create, modify, and delete
        teams. The credentials used must have the `manage_teams` permission set.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ns1 as ns1

        # Create a new NS1 Team
        example = ns1.Team("example",
            name="Example team",
            ip_whitelists=[
                {
                    "name": "whitelist-1",
                    "values": [
                        "1.1.1.1",
                        "2.2.2.2",
                    ],
                },
                {
                    "name": "whitelist-2",
                    "values": [
                        "3.3.3.3",
                        "4.4.4.4",
                    ],
                },
            ],
            dns_view_zones=False,
            account_manage_users=False)
        # Another team
        example2 = ns1.Team("example2",
            name="another team",
            dns_view_zones=True,
            dns_zones_allow_by_default=True,
            dns_zones_allows=["mytest.zone"],
            dns_zones_denies=["myother.zone"],
            dns_records_allows=[{
                "domain": "terraform.example.io",
                "include_subdomains": False,
                "zone": "example.io",
                "type": "A",
            }],
            data_manage_datasources=True)
        ```

        ## NS1 Documentation

        [Team Api Docs](https://ns1.com/api#team)

        ## Import

        ```sh
        $ pulumi import ns1:index/team:Team <name> <team_id>`
        ```

        :param str resource_name: The name of the resource.
        :param TeamArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TeamArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_manage_account_settings: Optional[pulumi.Input[bool]] = None,
                 account_manage_apikeys: Optional[pulumi.Input[bool]] = None,
                 account_manage_ip_whitelist: Optional[pulumi.Input[bool]] = None,
                 account_manage_payment_methods: Optional[pulumi.Input[bool]] = None,
                 account_manage_plan: Optional[pulumi.Input[bool]] = None,
                 account_manage_teams: Optional[pulumi.Input[bool]] = None,
                 account_manage_users: Optional[pulumi.Input[bool]] = None,
                 account_view_activity_log: Optional[pulumi.Input[bool]] = None,
                 account_view_invoices: Optional[pulumi.Input[bool]] = None,
                 data_manage_datafeeds: Optional[pulumi.Input[bool]] = None,
                 data_manage_datasources: Optional[pulumi.Input[bool]] = None,
                 data_push_to_datafeeds: Optional[pulumi.Input[bool]] = None,
                 dns_manage_zones: Optional[pulumi.Input[bool]] = None,
                 dns_records_allows: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TeamDnsRecordsAllowArgs', 'TeamDnsRecordsAllowArgsDict']]]]] = None,
                 dns_records_denies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TeamDnsRecordsDenyArgs', 'TeamDnsRecordsDenyArgsDict']]]]] = None,
                 dns_view_zones: Optional[pulumi.Input[bool]] = None,
                 dns_zones_allow_by_default: Optional[pulumi.Input[bool]] = None,
                 dns_zones_allows: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dns_zones_denies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 ip_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TeamIpWhitelistArgs', 'TeamIpWhitelistArgsDict']]]]] = None,
                 monitoring_create_jobs: Optional[pulumi.Input[bool]] = None,
                 monitoring_delete_jobs: Optional[pulumi.Input[bool]] = None,
                 monitoring_manage_jobs: Optional[pulumi.Input[bool]] = None,
                 monitoring_manage_lists: Optional[pulumi.Input[bool]] = None,
                 monitoring_update_jobs: Optional[pulumi.Input[bool]] = None,
                 monitoring_view_jobs: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 security_manage_active_directory: Optional[pulumi.Input[bool]] = None,
                 security_manage_global2fa: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TeamArgs.__new__(TeamArgs)

            __props__.__dict__["account_manage_account_settings"] = account_manage_account_settings
            __props__.__dict__["account_manage_apikeys"] = account_manage_apikeys
            __props__.__dict__["account_manage_ip_whitelist"] = account_manage_ip_whitelist
            __props__.__dict__["account_manage_payment_methods"] = account_manage_payment_methods
            __props__.__dict__["account_manage_plan"] = account_manage_plan
            __props__.__dict__["account_manage_teams"] = account_manage_teams
            __props__.__dict__["account_manage_users"] = account_manage_users
            __props__.__dict__["account_view_activity_log"] = account_view_activity_log
            __props__.__dict__["account_view_invoices"] = account_view_invoices
            __props__.__dict__["data_manage_datafeeds"] = data_manage_datafeeds
            __props__.__dict__["data_manage_datasources"] = data_manage_datasources
            __props__.__dict__["data_push_to_datafeeds"] = data_push_to_datafeeds
            __props__.__dict__["dns_manage_zones"] = dns_manage_zones
            __props__.__dict__["dns_records_allows"] = dns_records_allows
            __props__.__dict__["dns_records_denies"] = dns_records_denies
            __props__.__dict__["dns_view_zones"] = dns_view_zones
            __props__.__dict__["dns_zones_allow_by_default"] = dns_zones_allow_by_default
            __props__.__dict__["dns_zones_allows"] = dns_zones_allows
            __props__.__dict__["dns_zones_denies"] = dns_zones_denies
            __props__.__dict__["ip_whitelists"] = ip_whitelists
            __props__.__dict__["monitoring_create_jobs"] = monitoring_create_jobs
            __props__.__dict__["monitoring_delete_jobs"] = monitoring_delete_jobs
            __props__.__dict__["monitoring_manage_jobs"] = monitoring_manage_jobs
            __props__.__dict__["monitoring_manage_lists"] = monitoring_manage_lists
            __props__.__dict__["monitoring_update_jobs"] = monitoring_update_jobs
            __props__.__dict__["monitoring_view_jobs"] = monitoring_view_jobs
            __props__.__dict__["name"] = name
            __props__.__dict__["security_manage_active_directory"] = security_manage_active_directory
            __props__.__dict__["security_manage_global2fa"] = security_manage_global2fa
        super(Team, __self__).__init__(
            'ns1:index/team:Team',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_manage_account_settings: Optional[pulumi.Input[bool]] = None,
            account_manage_apikeys: Optional[pulumi.Input[bool]] = None,
            account_manage_ip_whitelist: Optional[pulumi.Input[bool]] = None,
            account_manage_payment_methods: Optional[pulumi.Input[bool]] = None,
            account_manage_plan: Optional[pulumi.Input[bool]] = None,
            account_manage_teams: Optional[pulumi.Input[bool]] = None,
            account_manage_users: Optional[pulumi.Input[bool]] = None,
            account_view_activity_log: Optional[pulumi.Input[bool]] = None,
            account_view_invoices: Optional[pulumi.Input[bool]] = None,
            data_manage_datafeeds: Optional[pulumi.Input[bool]] = None,
            data_manage_datasources: Optional[pulumi.Input[bool]] = None,
            data_push_to_datafeeds: Optional[pulumi.Input[bool]] = None,
            dns_manage_zones: Optional[pulumi.Input[bool]] = None,
            dns_records_allows: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TeamDnsRecordsAllowArgs', 'TeamDnsRecordsAllowArgsDict']]]]] = None,
            dns_records_denies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TeamDnsRecordsDenyArgs', 'TeamDnsRecordsDenyArgsDict']]]]] = None,
            dns_view_zones: Optional[pulumi.Input[bool]] = None,
            dns_zones_allow_by_default: Optional[pulumi.Input[bool]] = None,
            dns_zones_allows: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            dns_zones_denies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            ip_whitelists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TeamIpWhitelistArgs', 'TeamIpWhitelistArgsDict']]]]] = None,
            monitoring_create_jobs: Optional[pulumi.Input[bool]] = None,
            monitoring_delete_jobs: Optional[pulumi.Input[bool]] = None,
            monitoring_manage_jobs: Optional[pulumi.Input[bool]] = None,
            monitoring_manage_lists: Optional[pulumi.Input[bool]] = None,
            monitoring_update_jobs: Optional[pulumi.Input[bool]] = None,
            monitoring_view_jobs: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            security_manage_active_directory: Optional[pulumi.Input[bool]] = None,
            security_manage_global2fa: Optional[pulumi.Input[bool]] = None) -> 'Team':
        """
        Get an existing Team resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] account_manage_account_settings: Whether the team can modify account settings.
        :param pulumi.Input[bool] account_manage_apikeys: Whether the team can modify account apikeys.
        :param pulumi.Input[bool] account_manage_ip_whitelist: Whether the team can manage ip whitelist.
        :param pulumi.Input[bool] account_manage_payment_methods: Whether the team can modify account payment methods.
        :param pulumi.Input[bool] account_manage_plan: No longer in use.
        :param pulumi.Input[bool] account_manage_teams: Whether the team can modify other teams in the account.
        :param pulumi.Input[bool] account_manage_users: Whether the team can modify account users.
        :param pulumi.Input[bool] account_view_activity_log: Whether the team can view activity logs.
        :param pulumi.Input[bool] account_view_invoices: Whether the team can view invoices.
        :param pulumi.Input[bool] data_manage_datafeeds: Whether the team can modify data feeds.
        :param pulumi.Input[bool] data_manage_datasources: Whether the team can modify data sources.
        :param pulumi.Input[bool] data_push_to_datafeeds: Whether the team can publish to data feeds.
        :param pulumi.Input[bool] dns_manage_zones: Whether the team can modify the accounts zones.
        :param pulumi.Input[Sequence[pulumi.Input[Union['TeamDnsRecordsAllowArgs', 'TeamDnsRecordsAllowArgsDict']]]] dns_records_allows: List of records that the team may access.
        :param pulumi.Input[Sequence[pulumi.Input[Union['TeamDnsRecordsDenyArgs', 'TeamDnsRecordsDenyArgsDict']]]] dns_records_denies: List of records that the team may not access.
        :param pulumi.Input[bool] dns_view_zones: Whether the team can view the accounts zones.
        :param pulumi.Input[bool] dns_zones_allow_by_default: If true, enable the `dns_zones_allow` list, otherwise enable the `dns_zones_deny` list.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_zones_allows: List of zones that the team may access.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] dns_zones_denies: List of zones that the team may not access.
        :param pulumi.Input[Sequence[pulumi.Input[Union['TeamIpWhitelistArgs', 'TeamIpWhitelistArgsDict']]]] ip_whitelists: Array of IP addresses objects to chich to grant the team access. Each object includes a **name** (string), and **values** (array of strings) associated to each "allow" list.
        :param pulumi.Input[bool] monitoring_create_jobs: Whether the user can create monitoring jobs when manage_jobs is not set to true.
        :param pulumi.Input[bool] monitoring_delete_jobs: Whether the user can delete monitoring jobs when manage_jobs is not set to true.
        :param pulumi.Input[bool] monitoring_manage_jobs: Whether the user can create, update, and delete monitoring jobs.
        :param pulumi.Input[bool] monitoring_manage_lists: Whether the team can modify notification lists.
        :param pulumi.Input[bool] monitoring_update_jobs: Whether the user can update monitoring jobs when manage_jobs is not set to true.
        :param pulumi.Input[bool] monitoring_view_jobs: Whether the team can view monitoring jobs.
        :param pulumi.Input[str] name: The free form name of the team.
        :param pulumi.Input[bool] security_manage_active_directory: Whether the team can manage global active directory.
               Only relevant for the DDI product.
        :param pulumi.Input[bool] security_manage_global2fa: Whether the team can manage global two factor authentication.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TeamState.__new__(_TeamState)

        __props__.__dict__["account_manage_account_settings"] = account_manage_account_settings
        __props__.__dict__["account_manage_apikeys"] = account_manage_apikeys
        __props__.__dict__["account_manage_ip_whitelist"] = account_manage_ip_whitelist
        __props__.__dict__["account_manage_payment_methods"] = account_manage_payment_methods
        __props__.__dict__["account_manage_plan"] = account_manage_plan
        __props__.__dict__["account_manage_teams"] = account_manage_teams
        __props__.__dict__["account_manage_users"] = account_manage_users
        __props__.__dict__["account_view_activity_log"] = account_view_activity_log
        __props__.__dict__["account_view_invoices"] = account_view_invoices
        __props__.__dict__["data_manage_datafeeds"] = data_manage_datafeeds
        __props__.__dict__["data_manage_datasources"] = data_manage_datasources
        __props__.__dict__["data_push_to_datafeeds"] = data_push_to_datafeeds
        __props__.__dict__["dns_manage_zones"] = dns_manage_zones
        __props__.__dict__["dns_records_allows"] = dns_records_allows
        __props__.__dict__["dns_records_denies"] = dns_records_denies
        __props__.__dict__["dns_view_zones"] = dns_view_zones
        __props__.__dict__["dns_zones_allow_by_default"] = dns_zones_allow_by_default
        __props__.__dict__["dns_zones_allows"] = dns_zones_allows
        __props__.__dict__["dns_zones_denies"] = dns_zones_denies
        __props__.__dict__["ip_whitelists"] = ip_whitelists
        __props__.__dict__["monitoring_create_jobs"] = monitoring_create_jobs
        __props__.__dict__["monitoring_delete_jobs"] = monitoring_delete_jobs
        __props__.__dict__["monitoring_manage_jobs"] = monitoring_manage_jobs
        __props__.__dict__["monitoring_manage_lists"] = monitoring_manage_lists
        __props__.__dict__["monitoring_update_jobs"] = monitoring_update_jobs
        __props__.__dict__["monitoring_view_jobs"] = monitoring_view_jobs
        __props__.__dict__["name"] = name
        __props__.__dict__["security_manage_active_directory"] = security_manage_active_directory
        __props__.__dict__["security_manage_global2fa"] = security_manage_global2fa
        return Team(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountManageAccountSettings")
    def account_manage_account_settings(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the team can modify account settings.
        """
        return pulumi.get(self, "account_manage_account_settings")

    @property
    @pulumi.getter(name="accountManageApikeys")
    def account_manage_apikeys(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the team can modify account apikeys.
        """
        return pulumi.get(self, "account_manage_apikeys")

    @property
    @pulumi.getter(name="accountManageIpWhitelist")
    def account_manage_ip_whitelist(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the team can manage ip whitelist.
        """
        return pulumi.get(self, "account_manage_ip_whitelist")

    @property
    @pulumi.getter(name="accountManagePaymentMethods")
    def account_manage_payment_methods(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the team can modify account payment methods.
        """
        return pulumi.get(self, "account_manage_payment_methods")

    @property
    @pulumi.getter(name="accountManagePlan")
    @_utilities.deprecated("""obsolete, should no longer be used""")
    def account_manage_plan(self) -> pulumi.Output[Optional[bool]]:
        """
        No longer in use.
        """
        return pulumi.get(self, "account_manage_plan")

    @property
    @pulumi.getter(name="accountManageTeams")
    def account_manage_teams(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the team can modify other teams in the account.
        """
        return pulumi.get(self, "account_manage_teams")

    @property
    @pulumi.getter(name="accountManageUsers")
    def account_manage_users(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the team can modify account users.
        """
        return pulumi.get(self, "account_manage_users")

    @property
    @pulumi.getter(name="accountViewActivityLog")
    def account_view_activity_log(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the team can view activity logs.
        """
        return pulumi.get(self, "account_view_activity_log")

    @property
    @pulumi.getter(name="accountViewInvoices")
    def account_view_invoices(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the team can view invoices.
        """
        return pulumi.get(self, "account_view_invoices")

    @property
    @pulumi.getter(name="dataManageDatafeeds")
    def data_manage_datafeeds(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the team can modify data feeds.
        """
        return pulumi.get(self, "data_manage_datafeeds")

    @property
    @pulumi.getter(name="dataManageDatasources")
    def data_manage_datasources(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the team can modify data sources.
        """
        return pulumi.get(self, "data_manage_datasources")

    @property
    @pulumi.getter(name="dataPushToDatafeeds")
    def data_push_to_datafeeds(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the team can publish to data feeds.
        """
        return pulumi.get(self, "data_push_to_datafeeds")

    @property
    @pulumi.getter(name="dnsManageZones")
    def dns_manage_zones(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the team can modify the accounts zones.
        """
        return pulumi.get(self, "dns_manage_zones")

    @property
    @pulumi.getter(name="dnsRecordsAllows")
    def dns_records_allows(self) -> pulumi.Output[Optional[Sequence['outputs.TeamDnsRecordsAllow']]]:
        """
        List of records that the team may access.
        """
        return pulumi.get(self, "dns_records_allows")

    @property
    @pulumi.getter(name="dnsRecordsDenies")
    def dns_records_denies(self) -> pulumi.Output[Optional[Sequence['outputs.TeamDnsRecordsDeny']]]:
        """
        List of records that the team may not access.
        """
        return pulumi.get(self, "dns_records_denies")

    @property
    @pulumi.getter(name="dnsViewZones")
    def dns_view_zones(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the team can view the accounts zones.
        """
        return pulumi.get(self, "dns_view_zones")

    @property
    @pulumi.getter(name="dnsZonesAllowByDefault")
    def dns_zones_allow_by_default(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, enable the `dns_zones_allow` list, otherwise enable the `dns_zones_deny` list.
        """
        return pulumi.get(self, "dns_zones_allow_by_default")

    @property
    @pulumi.getter(name="dnsZonesAllows")
    def dns_zones_allows(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        List of zones that the team may access.
        """
        return pulumi.get(self, "dns_zones_allows")

    @property
    @pulumi.getter(name="dnsZonesDenies")
    def dns_zones_denies(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        List of zones that the team may not access.
        """
        return pulumi.get(self, "dns_zones_denies")

    @property
    @pulumi.getter(name="ipWhitelists")
    def ip_whitelists(self) -> pulumi.Output[Optional[Sequence['outputs.TeamIpWhitelist']]]:
        """
        Array of IP addresses objects to chich to grant the team access. Each object includes a **name** (string), and **values** (array of strings) associated to each "allow" list.
        """
        return pulumi.get(self, "ip_whitelists")

    @property
    @pulumi.getter(name="monitoringCreateJobs")
    def monitoring_create_jobs(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the user can create monitoring jobs when manage_jobs is not set to true.
        """
        return pulumi.get(self, "monitoring_create_jobs")

    @property
    @pulumi.getter(name="monitoringDeleteJobs")
    def monitoring_delete_jobs(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the user can delete monitoring jobs when manage_jobs is not set to true.
        """
        return pulumi.get(self, "monitoring_delete_jobs")

    @property
    @pulumi.getter(name="monitoringManageJobs")
    def monitoring_manage_jobs(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the user can create, update, and delete monitoring jobs.
        """
        return pulumi.get(self, "monitoring_manage_jobs")

    @property
    @pulumi.getter(name="monitoringManageLists")
    def monitoring_manage_lists(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the team can modify notification lists.
        """
        return pulumi.get(self, "monitoring_manage_lists")

    @property
    @pulumi.getter(name="monitoringUpdateJobs")
    def monitoring_update_jobs(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the user can update monitoring jobs when manage_jobs is not set to true.
        """
        return pulumi.get(self, "monitoring_update_jobs")

    @property
    @pulumi.getter(name="monitoringViewJobs")
    def monitoring_view_jobs(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the team can view monitoring jobs.
        """
        return pulumi.get(self, "monitoring_view_jobs")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The free form name of the team.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="securityManageActiveDirectory")
    def security_manage_active_directory(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the team can manage global active directory.
        Only relevant for the DDI product.
        """
        return pulumi.get(self, "security_manage_active_directory")

    @property
    @pulumi.getter(name="securityManageGlobal2fa")
    def security_manage_global2fa(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the team can manage global two factor authentication.
        """
        return pulumi.get(self, "security_manage_global2fa")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['TsigkeyArgs', 'Tsigkey']

@pulumi.input_type
class TsigkeyArgs:
    def __init__(__self__, *,
                 algorithm: pulumi.Input[str],
                 secret: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Tsigkey resource.
        :param pulumi.Input[str] algorithm: The algorithm used to hash the TSIG key's secret.
        :param pulumi.Input[str] secret: The key's secret to be hashed.
        :param pulumi.Input[str] name: The free form name of the tsigkey.
        """
        pulumi.set(__self__, "algorithm", algorithm)
        pulumi.set(__self__, "secret", secret)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def algorithm(self) -> pulumi.Input[str]:
        """
        The algorithm used to hash the TSIG key's secret.
        """
        return pulumi.get(self, "algorithm")

    @algorithm.setter
    def algorithm(self, value: pulumi.Input[str]):
        pulumi.set(self, "algorithm", value)

    @property
    @pulumi.getter
    def secret(self) -> pulumi.Input[str]:
        """
        The key's secret to be hashed.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: pulumi.Input[str]):
        pulumi.set(self, "secret", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The free form name of the tsigkey.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _TsigkeyState:
    def __init__(__self__, *,
                 algorithm: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 secret: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Tsigkey resources.
        :param pulumi.Input[str] algorithm: The algorithm used to hash the TSIG key's secret.
        :param pulumi.Input[str] name: The free form name of the tsigkey.
        :param pulumi.Input[str] secret: The key's secret to be hashed.
        """
        if algorithm is not None:
            pulumi.set(__self__, "algorithm", algorithm)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)

    @property
    @pulumi.getter
    def algorithm(self) -> Optional[pulumi.Input[str]]:
        """
        The algorithm used to hash the TSIG key's secret.
        """
        return pulumi.get(self, "algorithm")

    @algorithm.setter
    def algorithm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "algorithm", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The free form name of the tsigkey.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[str]]:
        """
        The key's secret to be hashed.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret", value)


class Tsigkey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 algorithm: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 secret: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a NS1 TSIG Key resource. This can be used to create, modify, and delete TSIG keys.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ns1 as ns1

        example = ns1.Tsigkey("example",
            name="ExampleTsigKey",
            algorithm="hmac-sha256",
            secret="Ok1qR5IW1ajVka5cHPEJQIXfLyx5V3PSkFBROAzOn21JumDq6nIpoj6H8rfj5Uo+Ok55ZWQ0Wgrf302fDscHLA==")
        ```
        ## NS1 Documentation

        [TSIG Keys Api Doc](https://ns1.com/api/#tsig)

        ## Import

        ```sh
        $ pulumi import ns1:index/tsigkey:Tsigkey importTest <name>`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] algorithm: The algorithm used to hash the TSIG key's secret.
        :param pulumi.Input[str] name: The free form name of the tsigkey.
        :param pulumi.Input[str] secret: The key's secret to be hashed.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TsigkeyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a NS1 TSIG Key resource. This can be used to create, modify, and delete TSIG keys.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ns1 as ns1

        example = ns1.Tsigkey("example",
            name="ExampleTsigKey",
            algorithm="hmac-sha256",
            secret="Ok1qR5IW1ajVka5cHPEJQIXfLyx5V3PSkFBROAzOn21JumDq6nIpoj6H8rfj5Uo+Ok55ZWQ0Wgrf302fDscHLA==")
        ```
        ## NS1 Documentation

        [TSIG Keys Api Doc](https://ns1.com/api/#tsig)

        ## Import

        ```sh
        $ pulumi import ns1:index/tsigkey:Tsigkey importTest <name>`
        ```

        :param str resource_name: The name of the resource.
        :param TsigkeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TsigkeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 algorithm: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 secret: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TsigkeyArgs.__new__(TsigkeyArgs)

            if algorithm is None and not opts.urn:
                raise TypeError("Missing required property 'algorithm'")
            __props__.__dict__["algorithm"] = algorithm
            __props__.__dict__["name"] = name
            if secret is None and not opts.urn:
                raise TypeError("Missing required property 'secret'")
            __props__.__dict__["secret"] = secret
        super(Tsigkey, __self__).__init__(
            'ns1:index/tsigkey:Tsigkey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            algorithm: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            secret: Optional[pulumi.Input[str]] = None) -> 'Tsigkey':
        """
        Get an existing Tsigkey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] algorithm: The algorithm used to hash the TSIG key's secret.
        :param pulumi.Input[str] name: The free form name of the tsigkey.
        :param pulumi.Input[str] secret: The key's secret to be hashed.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TsigkeyState.__new__(_TsigkeyState)

        __props__.__dict__["algorithm"] = algorithm
        __props__.__dict__["name"] = name
        __props__.__dict__["secret"] = secret
        return Tsigkey(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def algorithm(self) -> pulumi.Output[str]:
        """
        The algorithm used to hash the TSIG key's secret.
        """
        return pulumi.get(self, "algorithm")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The free form name of the tsigkey.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def secret(self) -> pulumi.Output[str]:
        """
        The key's secret to be hashed.
        """
        return pulumi.get(self, "secret")

